DownloadHelper class

Constructors

DownloadHelper()

Properties

cacheDefaultDuration int
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

downloadFile(String url, {String? fileName, int? cacheInMinutes}) Future<String?>
getDownloadProgress() Stream<double>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited