build method
Describes the part of the user interface represented by this widget.
The framework calls this method when this widget is inserted into the tree in a given BuildContext and when the dependencies of this widget change (e.g., an InheritedWidget referenced by this widget changes). This method can potentially be called in every frame and should not have any side effects beyond building a widget.
The framework replaces the subtree below this widget with the widget returned by this method, either by updating the existing subtree or by removing the subtree and inflating a new subtree, depending on whether the widget returned by this method can update the root of the existing subtree, as determined by calling Widget.canUpdate.
Typically implementations return a newly created constellation of widgets that are configured with information from this widget's constructor and from the given BuildContext.
The given BuildContext contains information about the location in the tree at which this widget is being built. For example, the context provides the set of inherited widgets for this location in the tree. A given widget might be built with multiple different BuildContext arguments over time if the widget is moved around the tree or if the widget is inserted into the tree in multiple places at once.
The implementation of this method must only depend on:
- the fields of the widget, which themselves must not change over time, and
- any ambient state obtained from the
contextusing BuildContext.dependOnInheritedWidgetOfExactType.
If a widget's build method is to depend on anything else, use a StatefulWidget instead.
See also:
- StatelessWidget, which contains the discussion on performance considerations.
Implementation
@override
Widget build(BuildContext context) {
return Scaffold(
appBar: AppBar(title: const Text('Text Style Converter')),
body: SingleChildScrollView(
padding: const EdgeInsets.all(16.0),
child: Column(
crossAxisAlignment: CrossAxisAlignment.start,
children: [
const Text('Pure Markdown Style:', style: TextStyle(fontSize: 18, fontWeight: FontWeight.bold)),
const SizedBox(height: 8),
"This is **bold** text, *italic* text, __underlined__ text, ~~strikethrough~~ text, and `code` text.".toRichText(
baseStyle: const TextStyle(fontSize: 16),
boldStyle: const TextStyle(fontWeight: FontWeight.bold, color: Colors.blue),
italicStyle: const TextStyle(fontStyle: FontStyle.italic, color: Colors.green),
underlineStyle: const TextStyle(decoration: TextDecoration.underline, color: Colors.purple),
strikethroughStyle: const TextStyle(decoration: TextDecoration.lineThrough, color: Colors.red),
codeStyle: const TextStyle(
fontFamily: 'monospace',
backgroundColor: Colors.grey,
color: Colors.white,
),
),
const SizedBox(height: 24),
const Text('Pure WhatsApp Style:', style: TextStyle(fontSize: 18, fontWeight: FontWeight.bold)),
const SizedBox(height: 8),
"This is *bold* text, _italic_ text, ~strikethrough~ text, and ```code``` text.".toRichText(
baseStyle: const TextStyle(fontSize: 16),
boldStyle: const TextStyle(fontWeight: FontWeight.bold, color: Colors.blue),
italicStyle: const TextStyle(fontStyle: FontStyle.italic, color: Colors.green),
strikethroughStyle: const TextStyle(decoration: TextDecoration.lineThrough, color: Colors.red),
codeStyle: const TextStyle(
fontFamily: 'monospace',
backgroundColor: Colors.grey,
color: Colors.white,
),
),
const SizedBox(height: 24),
const Text('Mixed Style:', style: TextStyle(fontSize: 18, fontWeight: FontWeight.bold)),
const SizedBox(height: 8),
"Mix **markdown bold** with *WhatsApp bold*, __markdown underline__ with _italic_, ~~markdown strikethrough~~ with ~WhatsApp strikethrough~, and `markdown code` with ```WhatsApp code```."
.toRichText(
baseStyle: const TextStyle(fontSize: 16),
boldStyle: const TextStyle(fontWeight: FontWeight.bold, color: Colors.blue),
italicStyle: const TextStyle(fontStyle: FontStyle.italic, color: Colors.green),
underlineStyle: const TextStyle(decoration: TextDecoration.underline, color: Colors.purple),
strikethroughStyle: const TextStyle(decoration: TextDecoration.lineThrough, color: Colors.red),
codeStyle: const TextStyle(
fontFamily: 'monospace',
backgroundColor: Colors.grey,
color: Colors.white,
),
),
const SizedBox(height: 24),
const Text('Nested Formatting:', style: TextStyle(fontSize: 18, fontWeight: FontWeight.bold)),
const SizedBox(height: 8),
"This has **bold with _nested italic_ text** and *bold with __nested underline__ text*.".toRichText(
baseStyle: const TextStyle(fontSize: 16),
boldStyle: const TextStyle(fontWeight: FontWeight.bold, color: Colors.blue),
italicStyle: const TextStyle(fontStyle: FontStyle.italic, color: Colors.green),
underlineStyle: const TextStyle(decoration: TextDecoration.underline, color: Colors.purple),
),
const SizedBox(height: 24),
const Text('Complex Example:', style: TextStyle(fontSize: 18, fontWeight: FontWeight.bold)),
const SizedBox(height: 8),
"Chat message: Hey! Check out this **amazing** _feature_ - it supports ~old syntax~ ~~new syntax~~ and even `inline code` plus ```code blocks```. **Pretty *cool* right?**".toRichText(
baseStyle: const TextStyle(fontSize: 16),
boldStyle: const TextStyle(fontWeight: FontWeight.bold, color: Colors.indigo),
italicStyle: const TextStyle(fontStyle: FontStyle.italic, color: Colors.teal),
strikethroughStyle: const TextStyle(decoration: TextDecoration.lineThrough, color: Colors.orange),
codeStyle: const TextStyle(
fontFamily: 'monospace',
backgroundColor: Colors.blueGrey,
color: Colors.white,
),
),
],
),
),
);
}