ChatDateTimeUtils class

Utility class for DateTime chat operations

Constructors

ChatDateTimeUtils()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

currentTimestamp int
Gets current timestamp in milliseconds
no setter
currentTimestampSeconds int
Gets current timestamp in seconds
no setter

Static Methods

fromTimestamp(int timestamp) DateTime
Creates DateTime from timestamp (supports both seconds and milliseconds)
fromTimestampString(String timestamp) DateTime
Creates DateTime from timestamp string
getTimeDifference(DateTime from, DateTime to) String
Gets time difference description
groupMessagesByDate<T>(List<T> messages, DateTime getDateTime(T)) Map<String, List<T>>
Groups messages by date sections
isSameDay(DateTime date1, DateTime date2) bool
Checks if two dates are on the same day