DanUIFormInputText<T> class

Inheritance

Constructors

DanUIFormInputText({Key? key, required TextEditingController controller, FocusNode? focusNode, Widget? label, Widget? prefixIcon, dynamic onTapPrefixIcon()?, bool useSeparator = false, Color separatorColor = Colors.black54, double separatorHeight = 24, double separatorSpace = 10, TextStyle? style, String? hintText, TextStyle? hintStyle, String? errorMessage, TextStyle? errorStyle, bool showBorder = true, double borderRadius = 8, Color? borderColor, Color? borderDisabledColor, Color? borderFocusedColor, Color? borderErrorColor, TextInputType? keyboardType, List<TextInputFormatter>? inputFormatters, dynamic onChanged(String)?, String? validator(String?)?, int? minLines, int? maxLines, TextInputAction? textInputAction, bool? enabled, EdgeInsets? contentPadding})
const

Properties

borderColor Color?
final
borderDisabledColor Color?
final
borderErrorColor Color?
final
borderFocusedColor Color?
final
borderRadius double
final
contentPadding EdgeInsets?
final
controller TextEditingController
final
enabled bool?
final
errorMessage String?
final
errorStyle TextStyle?
final
focusNode FocusNode?
final
hashCode int
The hash code for this object.
no setterinherited
hintStyle TextStyle?
final
hintText String?
final
inputFormatters List<TextInputFormatter>?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
keyboardType TextInputType?
final
label Widget?
final
maxLines int?
final
minLines int?
final
onChanged → dynamic Function(String)?
final
onTapPrefixIcon → dynamic Function()?
final
prefixIcon Widget?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
separatorColor Color
final
separatorHeight double
final
separatorSpace double
final
showBorder bool
final
style TextStyle?
final
textInputAction TextInputAction?
final
useSeparator bool
final
validator String? Function(String?)?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<DanUIFormInputText>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited