DanUIHelpers class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
composeEmail(
String emailAddress, {String? subject, String? body}) → Future< void> -
compressImage(
File file) → Future< File?> -
compressVideo(
File file, {bool compressVideo = false, int maxSizeBytes = 10 * 1024 * 1024}) → Future< File?> -
generateThumbnail(
XFile file) → Future< File?> -
generateThumbnailWithProgress(
String url, void onProgress(double)) → Future< File?> -
isValidLocalImage(
String url) → Future< bool> -
isValidNetworkImage(
String url) → Future< bool> -
openMailApp(
BuildContext context) → Future< void>